@@ -26,7 +26,7 @@ class CollectionCloner:
         self.des_db_name = self.config.get('des_db_name', '')
         self.user = self.config.get('user', '')
         self.password = self.config.get('password', '')
-        self.des_col = self.config.get('des_col', '')
+        self.des_col_name = self.config.get('des_col', '')
         self.des_ip = self.config.get('des_ip', '')
         
         if self.mode == 'll':
@@ -50,7 +50,7 @@ class CollectionCloner:
             logger.error('No src_col is found')
         if self.des_db_name == '':
             logger.error('No des_db_name is found')
-        if self.des_col == '':
+        if self.des_col_name == '':
             logger.error('No des_col is found')
         
         try:
@@ -66,7 +66,7 @@ class CollectionCloner:
         # Destinatoion 
         if self.des_db_name == '':
             logger.error('No des_db_name is found')
-        if self.des_col == '':
+        if self.des_col_name == '':
             logger.error('No des_col is found')
 
         try:
@@ -78,8 +78,10 @@ class CollectionCloner:
             des_db = des_client[self.des_db_name]
         except Exception as e:
             logger.error('Could not find destination database')
+
+        des_collection = des_db[self.des_col_name]
         
-        self.start_cloning(src_db, des_db)
+        self.start_cloning(src_db, des_collection)
     
     def clone_local_to_remote(self):
         if self.src_db_name == '':
@@ -104,7 +106,7 @@ class CollectionCloner:
             logger.error('No user is found')
         if self.password == '':
             logger.error('No password is found')
-        if self.des_col == '':
+        if self.des_col_name == '':
             logger.error('No des_col is found')
         if self.des_ip == '':
             logger.error('No des_ip is found')
@@ -125,6 +127,8 @@ class CollectionCloner:
             des_db = des_client[self.des_db_name]
         except Exception as e:
             logger.error('Could not find destination database')
+
+        des_collection = des_db[self.des_col_name]
         
         self.start_cloning(src_db, des_db)
         
@@ -167,6 +171,8 @@ class CollectionCloner:
             des_db = des_client[self.des_db_name]
         except Exception as e:
             logger.error('Could not find destination database')
+
+        des_collection = des_db[self.des_col_name]
         
         self.start_cloning(src_db, des_db)
         
@@ -207,7 +213,7 @@ class CollectionCloner:
             logger.error('No user is found')
         if self.password == '':
             logger.error('No password is found')
-        if self.des_col == '':
+        if self.des_col_name == '':
             logger.error('No des_col is found')
         if self.des_ip == '':
             logger.error('No des_ip is found')
@@ -229,13 +235,16 @@ class CollectionCloner:
             des_db = des_client[self.des_db_name]
         except Exception as e:
             logger.error('Could not find destination database')
+
+        des_collection = des_db[self.des_col_name]
         
         self.start_cloning(src_db, des_db)
 
     # Cloning database
-    def start_cloning(self, src_db, des_db):
-        for doc in src_db[self.src_col].find():
+    def start_cloning(self, src_db, des_collection):
+        src_docs = src_db[self.src_col].find()
+        for doc in src_docs:
             try:
-                des_db[self.des_col].insert(doc)
+                des_collection.insert(doc)
             except Exception as e:
                 logger.debug('Could not insert document into destination collection')
\ No newline at end of file
